@@ -51,6 +51,12 @@ classicthemerestorerjso.ctr = {
 	  }
 	} catch(e){}
 	
+	try{
+	  if (this.appversion >= 44) {
+		document.getElementById("ClassicTRoptionsPane").setAttribute('fx44plus',true);
+	  }
+	} catch(e){}
+	
 	// restore last selected categories/tabs
 	document.getElementById("CtrRadioGroup").selectedIndex = this.prefs.getIntPref('pref_actindx');
 	document.getElementById("ctraddon_tabcolor_tabs").selectedIndex = this.prefs.getIntPref('pref_actindx2');
@@ -383,6 +389,7 @@ classicthemerestorerjso.ctr = {
 	  document.getElementById('ctraddon_pw_ctroldsearch').style.visibility = 'collapse';
 	  document.getElementById('ctraddon_lbsugres').style.visibility = 'collapse';
 	  document.getElementById('ctraddon_pw_lbsugresbox').style.visibility = 'collapse';
+	  document.getElementById('ctraddon_pw_urlbar_uc').style.visibility = 'collapse';
 	}
 
 	if (this.appversion >= 43) {
@@ -391,8 +398,20 @@ classicthemerestorerjso.ctr = {
 
 	if (this.appversion < 44) {
 	  document.getElementById('ctraddon_pw_altalertbox').style.visibility = 'collapse';
+	  document.getElementById('ctraddon_pw_urlbardropm2').style.visibility = 'collapse';
 	}
 
+	if (this.appversion < 45) {
+	  document.getElementById('ctraddon_pw_ibinfoico').style.visibility = 'collapse';
+	  document.getElementById('ctraddon_pw_ibinfoico2').style.visibility = 'collapse';
+	  document.getElementById('ctraddon_pw_iblabels').style.visibility = 'collapse';
+	}
+
+	if (this.appversion < 47) {
+	  document.getElementById('ctraddon_pw_hiderecentbm').style.visibility = 'collapse';
+	  document.getElementById('ctraddon_pw_hideeditbm').style.visibility = 'collapse';
+	}
+	
 
 	function PrefListener(branch_name, callback) {
 	  // Keeping a reference to the observed preference branch or it will get
@@ -482,7 +501,6 @@ classicthemerestorerjso.ctr = {
 	// update sub settings
 	this.ctrpwAppbuttonextra(this.prefs.getCharPref("appbutton"),false);
 	this.ctrpwAppbuttonColorExtra(this.prefs.getCharPref("appbuttonc"));
-	this.ctrpwTabEmptyFavicon(this.prefs.getBoolPref("emptyfavicon2"));
 	this.ctrpwCtrOldSearch(this.prefs.getBoolPref("ctroldsearch"));
 	this.ctrpwFaviconextra(this.prefs.getBoolPref("faviconurl"));
 	this.ctrpwBFextra(this.prefs.getBoolPref("backforward"));
@@ -496,6 +514,8 @@ classicthemerestorerjso.ctr = {
 	this.ctrpwNavBarPadding(this.prefs.getBoolPref("navbarpad"));
 	this.ctrpwLocationSearchbarSize(this.prefs.getBoolPref("lbsbsize"));
 	this.ctrpwCompactAddonList(this.prefs.getBoolPref("am_compact"));
+	this.ctrpwUnsortBM(this.prefs.getBoolPref("bmbunsortbm"));
+	this.ctrpwHideUrlStopRel(this.prefs.getBoolPref("hideurelstop"));
 	
 	var closetab_value = this.prefs.getCharPref("closetab");
   
@@ -624,12 +644,9 @@ classicthemerestorerjso.ctr = {
   },
   
   ctrpwFaviconextra: function(which) {
-    if(which==true) which=false; else which=true;
+	if(which==true) which=false; else which=true;
 	document.getElementById('ctraddon_padlock_extra').disabled = which;
-  },
-  
-  ctrpwTabEmptyFavicon: function(which) {
-	document.getElementById('ctraddon_pw_tab_emptyfavicon').disabled = which;
+	document.getElementById('ctraddon_pw_ibinfoico2').disabled = !which;
   },
   
   ctrpwBFextra: function(which) {
@@ -744,6 +761,32 @@ classicthemerestorerjso.ctr = {
 	document.getElementById('ctraddon_pw_am_compact2').style.visibility = itemvis;
   },
   
+  ctrpwUnsortBM: function(which) {
+	var itemvis = 'collapse';
+	
+    if(which==true) {
+	  which=false; itemvis = 'visible';
+	} else {
+	  which=true; itemvis = 'collapse';
+	}
+	
+    document.getElementById('ctraddon_pw_bmbunsortbm2').disabled = which;
+	document.getElementById('ctraddon_pw_bmbunsortbm2').style.visibility = itemvis;
+  },
+  
+  ctrpwHideUrlStopRel: function(which) {
+	var itemvis = 'collapse';
+	
+    if(which==true) {
+	  which=false; itemvis = 'visible';
+	} else {
+	  which=true; itemvis = 'collapse';
+	}
+	
+    document.getElementById('ctraddon_pw_hideurelstop2').disabled = which;
+	document.getElementById('ctraddon_pw_hideurelstop2').style.visibility = itemvis;
+  },
+ 
   ctrpwCtrOldSearch: function(which) {
 	var itemvis = 'collapse';
 	
@@ -880,6 +923,17 @@ classicthemerestorerjso.ctr = {
 	  document.getElementById('ctraddon_appbclmmenus').disabled = true;
 	  document.getElementById('ctraddon_pw_appbautocol').disabled = true;
 	  document.getElementById('ctraddon_pw_appbuttonct').disabled = true;
+	} else if (which=="appbutton_pm2"){
+	  document.getElementById('ctraddon_altabico_list').disabled = true;
+	  document.getElementById('ctraddon_abhigher').disabled = true;
+	  document.getElementById('ctraddon_appbutbdl').disabled = true;
+	  document.getElementById('ctraddon_appbutcolor_list').disabled = false;
+	  document.getElementById('ctraddon_dblclclosefx').disabled = true;
+	  document.getElementById('ctraddon_pw_appbutonclab').disabled = true;
+	  document.getElementById('ctraddon_pw_appbuttontxt').disabled = true;
+	  document.getElementById('ctraddon_appbclmmenus').disabled = true;
+	  document.getElementById('ctraddon_pw_appbautocol').disabled = true;
+	  document.getElementById('ctraddon_pw_appbuttonct').disabled = true;
 	} else if (which=="appbutton_v2io" || which=="appbutton_v2io2") {
 	  document.getElementById('ctraddon_altabico_list').disabled = true;
 	  document.getElementById('ctraddon_abhigher').disabled = true;
@@ -1004,7 +1058,7 @@ classicthemerestorerjso.ctr = {
 	this.prefs.setCharPref("findbar",'findbar_bottoma');
 	this.prefs.setBoolPref("hideprivmask",true);
 	this.prefs.setBoolPref("cpanelmenus",true);
-	this.prefs.setBoolPref("emptyfavicon",true);
+	this.prefs.setCharPref("emptyfavico_t",'emptyfavico_t_dot');
 	this.prefs.setBoolPref("hidezoomres",true);
 	this.prefs.setBoolPref("faviconurl",true);
 	this.prefs.setBoolPref("bmanimation",true);
@@ -1052,8 +1106,7 @@ classicthemerestorerjso.ctr = {
 	this.prefs.setBoolPref("activndicat",false);
 	this.prefs.setBoolPref("toolsitem",false);
 	this.prefs.setBoolPref("cuibuttons",false);
-	
-	if (this.oswindows) this.prefs.setBoolPref("dblclnewtab",true);
+	this.prefs.setBoolPref("addonversion",false);
 	
 	this.needsBrowserRestart();
 
