@@ -1,5 +1,4 @@
 // tab settings
-// tab settings
 pref("extensions.classicthemerestorer.tabs","tabs_squared");
 pref("extensions.classicthemerestorer.tabsontop",'unset');
 pref("extensions.classicthemerestorer.ctabheightcb",false);
@@ -7,11 +6,12 @@ pref("extensions.classicthemerestorer.square_edges",false);
 pref("extensions.classicthemerestorer.ctabheight",28);
 pref("extensions.classicthemerestorer.ctabmwidth",100);
 pref("extensions.classicthemerestorer.ctabwidth",210);
-pref("extensions.classicthemerestorer.emptyfavicon",false);
+pref("extensions.classicthemerestorer.emptyfavico_t",'emptyfavico_t_none');
 pref("extensions.classicthemerestorer.noemptypticon",false);
 pref("extensions.classicthemerestorer.closetab","closetab_default");
 pref("extensions.classicthemerestorer.closetabhfl",false);
 pref("extensions.classicthemerestorer.closeonleft",false);
+pref("extensions.classicthemerestorer.closetabbig",false);
 pref("extensions.classicthemerestorer.closeicon",'closeicon_default');
 pref("extensions.classicthemerestorer.tttitlebar",false);
 
@@ -51,7 +51,7 @@ pref("extensions.classicthemerestorer.iat_notf_vt",false);
 pref("extensions.classicthemerestorer.wincontrols",false);
 pref("extensions.classicthemerestorer.oldtoplevimg",false);
 pref("extensions.classicthemerestorer.altalertbox",false);
-pref("extensions.classicthemerestorer.emptyfavicon2",false);
+pref("extensions.classicthemerestorer.emptyfavico_g",'emptyfavico_g_def');
 pref("extensions.classicthemerestorer.panelmenucol",false);
 pref("extensions.classicthemerestorer.cpanelmenus",false);
 pref("extensions.classicthemerestorer.hidezoomres",false);
@@ -60,15 +60,20 @@ pref("extensions.classicthemerestorer.ctroldsearch",false);
 pref("extensions.classicthemerestorer.ctroldsearchc",false);
 pref("extensions.classicthemerestorer.osearch_meoit",false);
 pref("extensions.classicthemerestorer.osearch_dm",false);
-pref("extensions.classicthemerestorer.addonversion",false);
+pref("extensions.classicthemerestorer.addonversion",true);
 pref("extensions.classicthemerestorer.alt_addonsm",false);
 pref("extensions.classicthemerestorer.am_nowarning",false);
 pref("extensions.classicthemerestorer.am_compact",false);
 pref("extensions.classicthemerestorer.am_compact2",true);
 pref("extensions.classicthemerestorer.am_highlight",false);
+pref("extensions.classicthemerestorer.am_buticons",false);
+pref("extensions.classicthemerestorer.am_hovshowb",false);
 pref("extensions.classicthemerestorer.alt_addonsp",false);
+pref("extensions.classicthemerestorer.hiderecentbm",false);
+pref("extensions.classicthemerestorer.hideeditbm",false);
 pref("extensions.classicthemerestorer.bmbutpanelm",false);
 pref("extensions.classicthemerestorer.bmbunsortbm",false);
+pref("extensions.classicthemerestorer.bmbunsortbm2",true);
 pref("extensions.classicthemerestorer.bmbviewbmtb",false);
 pref("extensions.classicthemerestorer.bmbnounsort",false);
 pref("extensions.classicthemerestorer.bmbutnotext",false);
@@ -104,15 +109,20 @@ pref("extensions.classicthemerestorer.tabseparator","tabsep_default");
 pref("extensions.classicthemerestorer.starinurl",false);
 pref("extensions.classicthemerestorer.feedinurl",false);
 pref("extensions.classicthemerestorer.hideurelstop",false);
+pref("extensions.classicthemerestorer.hideurelstop2",false);
 pref("extensions.classicthemerestorer.hideurlgo",false);
 pref("extensions.classicthemerestorer.hideurlsrg",false);
 pref("extensions.classicthemerestorer.hideprbutton",false);
 pref("extensions.classicthemerestorer.urlbardropm",false);
+pref("extensions.classicthemerestorer.urlbardropm2",false);
 pref("extensions.classicthemerestorer.altreaderico",false);
 
 pref("extensions.classicthemerestorer.ib_nohovcolor",false);
 pref("extensions.classicthemerestorer.ib_graycolor",false);
 pref("extensions.classicthemerestorer.verifiedcolors",false);
+pref("extensions.classicthemerestorer.ibinfoico",false);
+pref("extensions.classicthemerestorer.ibinfoico2",false);
+pref("extensions.classicthemerestorer.iblabels",false);
 pref("extensions.classicthemerestorer.faviconurl",false);
 pref("extensions.classicthemerestorer.padlock","padlock_default");
 pref("extensions.classicthemerestorer.padlockex",true);
@@ -162,6 +172,7 @@ pref("extensions.classicthemerestorer.menubarnofog",false);
 
 pref("extensions.classicthemerestorer.closeabarbut",false);
 pref("extensions.classicthemerestorer.highaddonsbar",false);
+pref("extensions.classicthemerestorer.lessaddonsbar",false);
 pref("extensions.classicthemerestorer.addonbarfs",false);
 pref("extensions.classicthemerestorer.noaddonbarbg",false);
 
@@ -189,6 +200,7 @@ pref("extensions.classicthemerestorer.contextitem",false);
 pref("extensions.classicthemerestorer.puictrbutton",false);
 pref("extensions.classicthemerestorer.cuibuttons",true);
 pref("extensions.classicthemerestorer.nodevtheme2",false);
+pref("extensions.classicthemerestorer.restartapp",true);
 pref("extensions.classicthemerestorer.pref_actindx",3);
 pref("extensions.classicthemerestorer.pref_actindx2",0);
 
@@ -260,7 +272,7 @@ pref("extensions.classicthemerestorer.tabc_hov_unl",false);
 pref("extensions.classicthemerestorer.optionsrem",true);
 pref("extensions.classicthemerestorer.aboutprefs",'category-general');
 pref("extensions.classicthemerestorer.aboutprefsInd",0);
-pref("extensions.classicthemerestorer.aboutprefsww",700);
+pref("extensions.classicthemerestorer.aboutprefsww",850);
 pref("extensions.classicthemerestorer.aboutprefswh",670);
 
 // first run/reset preference
